@@ -328,6 +328,7 @@ export default class ApplicationModel extends GenericModel {
         case 'Application':
         case 'Channel':
         case 'Subscription':
+        case 'ApplicationSet':
           ({ namespace } = metadata);
           if (namespace === null) {
             // namespace has all whitespace characters
@@ -381,7 +382,7 @@ export default class ApplicationModel extends GenericModel {
     let applicationResource;
     let applicationRequestPath;
     resources = resources.filter((resource, index) => {
-      if (resource.kind === 'Application') {
+      if (resource.kind === 'Application' || resource.kind === 'ApplicationSet') {
         applicationResource = resource;
         ([applicationRequestPath] = requestPaths.splice(index, 1));
         return false;
@@ -486,6 +487,25 @@ export default class ApplicationModel extends GenericModel {
         checkAndCollectError(destroyResponses);
 
         // don't update application--constantly changing
+        // patch applicationset spec
+        const { kind, spec, metadata } = applicationResource;
+        if (kind === 'ApplicationSet') {
+          const requestBody = {
+            body: [
+              {
+                op: 'replace',
+                path: '/spec',
+                value: spec,
+              },
+            ],
+          };
+          const patch = await this.kubeConnector.patch(`${applicationRequestPath}/${metadata.name}`, requestBody)
+            .catch((err) => ({
+              status: 'Failure',
+              message: err.message,
+            }));
+          checkAndCollectError(patch);
+        }
       } else {
         // if create, create the application
         const deployment = await this.kubeConnector.post(applicationRequestPath, applicationResource)
@@ -524,22 +544,14 @@ export default class ApplicationModel extends GenericModel {
   // ///////////// GET APPLICATION OVERVIEW ////////////////
 
   // for overview page
-  async getApplicationOverview(name, namespace = 'default') {
-    let apps;
-    try {
-      if (name) {
-        apps = await this.kubeConnector.getResources(
-          (ns) => `/apis/app.k8s.io/v1beta1/namespaces/${ns}/applications/${name}`,
-          { namespaces: [namespace] },
-        );
-      } else {
-        apps = await this.kubeConnector.getResources((ns) => `/apis/app.k8s.io/v1beta1/namespaces/${ns}/applications`);
-      }
-      apps = await Promise.all(apps);
-    } catch (err) {
+  async getApplicationOverview() {
+    const apps = _.flatten(await Promise.all([
+      this.kubeConnector.getResources((ns) => `/apis/app.k8s.io/v1beta1/namespaces/${ns}/applications`),
+      this.kubeConnector.getResources((ns) => `/apis/argoproj.io/v1alpha1/namespaces/${ns}/applications`),
+    ]).catch((err) => {
       logger.error(err);
       throw err;
-    }
+    }));
     return apps.filter((app) => app.metadata)
       .map((app) => ({
         metadata: app.metadata,
@@ -555,7 +567,9 @@ export default class ApplicationModel extends GenericModel {
     // get application
     let model = null;
     let apps = [];
+    let placement = [];
     const apiVersion = apiversion || 'app.k8s.io/v1beta1'; // defaults to ACM app
+    const isArgo = apiVersion.indexOf('argoproj.io') > -1;
     try {
       if (cluster) {
         // find Argo app on remote cluster
@@ -567,6 +581,9 @@ export default class ApplicationModel extends GenericModel {
           namespace,
         };
         const result = await this.getResource(args);
+        if (isArgo) {
+          placement = await this.getPlacement(result, apiVersion, namespace);
+        }
         if (!result) {
           const managedCluster = await this.kubeConnector.get(
             `/apis/cluster.open-cluster-management.io/v1/managedclusters/${cluster}`,
@@ -593,6 +610,19 @@ export default class ApplicationModel extends GenericModel {
           (ns) => `/apis/${apiVersion}/namespaces/${ns}/applications/${name}`,
           { namespaces: [namespace] },
         );
+        const appsetName = isArgo ? _.get(apps[0], 'metadata.ownerReferences[0].name', '') : '';
+        if (appsetName) {
+          apps = await this.kubeConnector.getResources(
+            (ns) => `/apis/argoproj.io/v1alpha1/namespaces/${ns}/applicationsets/${appsetName}`,
+            { namespaces: [namespace] },
+          );
+
+          const placementName = _.get(apps[0], 'spec.generators[0].clusterDecisionResource.labelSelector.matchLabels["cluster.open-cluster-management.io/placement"]', '');
+          placement = placementName ? await this.kubeConnector.getResources(
+            (ns) => `/apis/cluster.open-cluster-management.io/v1alpha1/namespaces/${ns}/placements/${placementName}`,
+            { namespaces: [namespace] },
+          ) : [];
+        }
       }
     } catch (err) {
       logger.error(err);
@@ -604,7 +634,7 @@ export default class ApplicationModel extends GenericModel {
 
       // get its associated resources
       model = {
-        name, namespace, app, metadata: app.metadata,
+        name, namespace, app, metadata: app.metadata, placement: placement[0],
       };
 
       if (_.get(app, 'apiVersion', '').indexOf('argoproj.io') > -1) {
@@ -667,6 +697,23 @@ export default class ApplicationModel extends GenericModel {
     return model;
   }
 
+  async getPlacement(resource, apiVersion, namespace) {
+    let placement = '';
+    const argoName = _.get(resource, 'metadata.ownerReferences[0].name', '');
+    if (argoName) {
+      const applicationset = await this.kubeConnector.getResources(
+        (ns) => `/apis/${apiVersion}/namespaces/${ns}/applicationsets/${argoName}`,
+        { namespaces: [namespace] },
+      );
+      const placementName = _.get(applicationset[0], 'spec.generators[0].clusterDecisionResource.labelSelector.matchLabels["cluster.open-cluster-management.io/placement"]', '');
+      placement = placementName ? await this.kubeConnector.getResources(
+        (ns) => `/apis/cluster.open-cluster-management.io/v1alpha1/namespaces/${ns}/placements/${placementName}`,
+        { namespaces: [namespace] },
+      ) : [];
+    }
+    return placement;
+  }
+
   async getApplications() {
     const apps = _.flatten(await Promise.all([
       this.kubeConnector.getResources((ns) => `/apis/app.k8s.io/v1beta1/namespaces/${ns}/applications`),
@@ -681,6 +728,55 @@ export default class ApplicationModel extends GenericModel {
     })), ['metadata.name', 'metadata.namespace']);
   }
 
+  async getApplicationSetRelatedResources(name, namespace) {
+    const argoServerNS = await this.getArgoServerNs();
+    const namespaces = [];
+
+    argoServerNS.argoServerNS.forEach((ns) => {
+      namespaces.push(ns.name);
+    });
+    const appSets = await this.kubeConnector.getResources(
+      (ns) => `/apis/argoproj.io/v1alpha1/namespaces/${ns}/applicationsets`,
+      { namespaces },
+    ).catch((err) => {
+      logger.error(err);
+      throw err;
+    });
+
+    const placementMap = {};
+    let appSetBeingDeleted;
+    let placement;
+
+    appSets.forEach((appSet) => {
+      const appSetName = _.get(appSet, 'metadata.name', '');
+      const appSetNamespace = _.get(appSet, 'metadata.namespace', '');
+      const appSetGenerators = _.get(appSet, 'spec.generators', []);
+      const appSetPlacement = appSetGenerators
+        ? _.get(appSetGenerators[0], 'clusterDecisionResource.labelSelector.matchLabels["cluster.open-cluster-management.io/placement"]', '')
+        : '';
+      if (name === appSetName && namespace === appSetNamespace) {
+        appSetBeingDeleted = appSet;
+        placement = appSetPlacement;
+      } else {
+        const placementEntry = placementMap[appSetPlacement];
+        if (placementEntry) {
+          placementEntry.push(appSetName);
+        } else if (appSetPlacement) {
+          placementMap[appSetPlacement] = [appSetName];
+        }
+      }
+    });
+
+    return {
+      appSetBeingDeleted: {
+        name: appSetBeingDeleted.metadata.name,
+        namespace: appSetBeingDeleted.metadata.namespace,
+      },
+      appSetPlacement: placement,
+      appSetsSharingPlacement: placementMap[placement] || [],
+    };
+  }
+
   async getAppDeployables(deployableMap) {
     const requests = Object.entries(deployableMap).map(async ([namespace, values]) => {
       // get all deployables in this namespace
@@ -897,12 +993,23 @@ export default class ApplicationModel extends GenericModel {
     return successImportStatus;
   }
 
+  async getArgoServerNs() {
+    const gitopsclusters = await this.kubeConnector.getResources((ns) => `/apis/apps.open-cluster-management.io/v1beta1/namespaces/${ns}/gitopsclusters`).catch((err) => {
+      logger.error(err);
+      throw err;
+    });
+    const argoNamespace = _.map(gitopsclusters, 'spec.argoServer.argoNamespace');
+    const argosNS = Object.assign(...argoNamespace.map((k) => ({ name: k })));
+    return { argoServerNS: [argosNS] };
+  }
+
   async getSecrets(labelObject) {
     const { label, value } = labelObject;
     const secrets = await this.kubeConnector.get(`/api/v1/secrets/?labelSelector=${encodeURIComponent(label)}`).catch((err) => {
       logger.error(err);
       throw err;
     });
+
     const ansibleSecrets = _.filter(_.get(secrets, 'items', []), (secret) => _.get(secret, 'metadata.labels', {})[label] === value);
     return ansibleSecrets.map((secret) => ({
       ansibleSecretName: _.get(secret, 'metadata.name', 'unknown'),
